Module: WizardOfAwes::HelperAuth
- Defined in:
- lib/wizard_of_awes/helper_auth.rb
Instance Method Summary collapse
-
#woa_authorize ⇒ Object
Simple auth.
Instance Method Details
#woa_authorize ⇒ Object
Simple auth. When implementing some other form of authorization
this method should return true if everything is great, or redirect user
to some other page, thus denying access to cms admin section.
5 6 7 8 9 10 11 |
# File 'lib/wizard_of_awes/helper_auth.rb', line 5 def # If things are good... # true # If things are not good redirect_to(root_path) end |